Crate naia_hecs_server

Crate naia_hecs_server 

Modules

transport

Structs

AuthEvent
ConnectEvent
DisconnectEvent
ErrorEvent
Protocol
Random
Container for cross-platform Random methods
RoomKey
Server
A server that uses either UDP or WebRTC communication to send/receive messages to/from connected clients, and syncs registered entities to clients to whom they are in-scope
ServerConfig
Contains Config properties which will be used by the Server
TickEvent
WorldWrapper

Traits

WorldProxy
WorldProxyMut