Modules
Structs
- Auth
Event - Connect
Event - Disconnect
Event - Error
Event - Protocol
- Random
- Container for cross-platform Random methods
- RoomKey
- Server
- A server that uses either UDP or WebRTC communication to send/receive messages to/from connected clients, and syncs registered entities to clients to whom they are in-scope
- Server
Config - Contains Config properties which will be used by the Server
- Tick
Event - World
Wrapper